#############################################################################
#
# MODULE:   	Grass Compilation
# AUTHOR(S):	Original author unknown - probably CERL
#		Markus Neteler - Germany/Italy - neteler@itc.it
#   	    	Justin Hickey - Thailand - jhickey@hpcc.nectec.or.th
#   	    	Huidae Cho - Korea - grass4u@gmail.com
#   	    	Eric G. Miller - egm2@jps.net
# PURPOSE:  	The source file for this Makefile is in src/CMD/head/head.in.
#		It is the top part of a file called make.rules which is used
#		for compiling all GRASS modules. This part of the file provides
#		make variables that are dependent on the results of the
#		configure script.
# COPYRIGHT:    (C) 2000 by the GRASS Development Team
#
#               This program is free software under the GNU General Public
#   	    	License (>=v2). Read the file COPYING that comes with GRASS
#   	    	for details.
#
#############################################################################

############################## Make Variables ###############################

CC                  = clang
CXX                 = clang++
LEX                 = flex
YACC                = bison -y
PERL                = @@HOMEBREW_PREFIX@@/opt/perl/bin/perl
AR                  = ar
RANLIB              = ranlib
MKDIR               = mkdir -p
CHMOD               = chmod
INSTALL             = /usr/bin/install -c 
INSTALL_DATA        = ${INSTALL} -m 644

prefix              = @@HOMEBREW_CELLAR@@/osgeo-grass/7.6.1_3
exec_prefix         = ${prefix}
ARCH                = x86_64-apple-darwin16.6.0
UNIX_BIN            = ${exec_prefix}/bin
INST_DIR            = ${prefix}/grass76

GRASS_HOME          = @@HOMEBREW_CELLAR@@/osgeo-grass/7.6.1_3/grass76
RUN_GISBASE         = @@HOMEBREW_CELLAR@@/osgeo-grass/7.6.1_3/grass76

GRASS_VERSION_MAJOR = 7
GRASS_VERSION_MINOR = 6
GRASS_VERSION_RELEASE = 1
GRASS_VERSION_DATE  = 2019
GRASS_VERSION_SVN   = exported

STRIPFLAG           = 
LD_SEARCH_FLAGS     = 
LD_LIBRARY_PATH_VAR = DYLD_LIBRARY_PATH

#generate static (ST) or shared (SH)
GRASS_LIBRARY_TYPE  = shlib

#static libs:
STLIB_LD            = ${AR} cr
STLIB_PREFIX        = lib
STLIB_SUFFIX        = .a

#shared libs
SHLIB_PREFIX        = lib
SHLIB_LD            = cc -dynamiclib -compatibility_version ${GRASS_VERSION_MAJOR}.${GRASS_VERSION_MINOR} -current_version ${GRASS_VERSION_MAJOR}.${GRASS_VERSION_MINOR} -install_name ${INST_DIR}/lib/lib${LIB_NAME}${SHLIB_SUFFIX}
SHLIB_LDFLAGS       = 
SHLIB_CFLAGS        = -fno-common
SHLIB_SUFFIX        = .dylib
EXE                 = 

DEFAULT_DATABASE    =
DEFAULT_LOCATION    =

CPPFLAGS            =   -I@@HOMEBREW_PREFIX@@/include
CFLAGS              = -I/Library/Java/JavaVirtualMachines/jdk1.8.0_131.jdk/Contents/Home/include -I/Library/Java/JavaVirtualMachines/jdk1.8.0_131.jdk/Contents/Home/include/darwin   -arch x86_64 -isysroot /Applications/Xcode-8.3.3.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.12.sdk
CXXFLAGS            = -I/Library/Java/JavaVirtualMachines/jdk1.8.0_131.jdk/Contents/Home/include -I/Library/Java/JavaVirtualMachines/jdk1.8.0_131.jdk/Contents/Home/include/darwin  -arch x86_64 -isysroot /Applications/Xcode-8.3.3.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.12.sdk
INCLUDE_DIRS        =  -I@@HOMEBREW_PREFIX@@/include
LINK_FLAGS          =   -arch x86_64 -isysroot /Applications/Xcode-8.3.3.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.12.sdk   -L@@HOMEBREW_PREFIX@@/LIB

DLLIB               = 
XCFLAGS             = 
XLIBPATH            = 
XLIB                =  -lSM -lICE -lX11
XEXTRALIBS          = 
USE_X11             = 1

MATHLIB             =  
ICONVLIB            = -liconv
INTLLIB             = -lintl
SOCKLIB             = 

#ZLIB:
ZLIB                =  -lz 
ZLIBINCPATH         =  -I@@HOMEBREW_PREFIX@@/opt/zlib/include
ZLIBLIBPATH         =  -L@@HOMEBREW_PREFIX@@/opt/zlib/lib

#BZIP2:
BZIP2LIB            =  -lbz2 
BZIP2INCPATH        =  -I@@HOMEBREW_PREFIX@@/opt/bzip2/include
BZIP2LIBPATH        =  -L@@HOMEBREW_PREFIX@@/opt/bzip2/lib

#ZSTD:
ZSTDLIB             =  -lzstd 
ZSTDINCPATH         =  -I@@HOMEBREW_PREFIX@@/opt/zstd/include
ZSTDLIBPATH         =  -L@@HOMEBREW_PREFIX@@/opt/zstd/lib

DBMIEXTRALIB        = 

#readline
READLINEINCPATH     =  -I@@HOMEBREW_PREFIX@@/opt/readline/include
READLINELIBPATH     =  -L@@HOMEBREW_PREFIX@@/opt/readline/lib
READLINELIB         =  -lreadline 
HISTORYLIB          =  -lhistory 

#PostgreSQL:
PQINCPATH           =  -I@@HOMEBREW_PREFIX@@/opt/osgeo-postgresql/include
PQLIBPATH           =  -L@@HOMEBREW_PREFIX@@/opt/osgeo-postgresql/lib
PQLIB               =  -lpq 
USE_POSTGRES        = 1

#MySQL:
MYSQLINCPATH        =  -I@@HOMEBREW_PREFIX@@/opt/mysql/include/mysql
MYSQLLIBPATH        =  -L@@HOMEBREW_PREFIX@@/opt/mysql/lib
MYSQLLIB            =  -lmysqlclient 
MYSQLDLIB           = 

#SQLite:
SQLITEINCPATH       =  -I@@HOMEBREW_PREFIX@@/opt/sqlite/include
SQLITELIBPATH       =  -L@@HOMEBREW_PREFIX@@/opt/sqlite/lib
SQLITELIB           =  -lsqlite3 

#ODBC:
ODBCINC             =  -I@@HOMEBREW_PREFIX@@/opt/unixodbc/include
ODBCLIB             =  -L@@HOMEBREW_PREFIX@@/opt/unixodbc/lib -lodbc 

#Image formats:
PNGINC              =  -I@@HOMEBREW_PREFIX@@/opt/libpng/include
PNGLIB              =  -L@@HOMEBREW_PREFIX@@/opt/libpng/lib -lpng  -lz  
USE_PNG             = 1

TIFFINCPATH         =  -I@@HOMEBREW_PREFIX@@/opt/libtiff/include
TIFFLIBPATH         =  -L@@HOMEBREW_PREFIX@@/opt/libtiff/lib
TIFFLIB             =  -ltiff 

#openGL files for NVIZ/r3.showdspf
OPENGLINC           =  -I/Applications/Xcode-8.3.3.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.12.sdk/System/Library/Frameworks/OpenGL.framework/Headers
OPENGLLIB           =   -lGL 
OPENGLULIB          =   -lGLU 
OPENGL_X11          = 1
OPENGL_AQUA         = 
OPENGL_WINDOWS      = 
USE_OPENGL          = 1

#FFTW:
FFTWINC             =  -I@@HOMEBREW_PREFIX@@/opt/fftw/include
FFTWLIB             =  -L@@HOMEBREW_PREFIX@@/opt/fftw/lib -lfftw3 

#LAPACK/BLAS stuff for gmath lib:
BLASLIB             = -lblas
BLASINC             =  -I@@HOMEBREW_PREFIX@@/opt/openblas/include
LAPACKLIB           =  -L@@HOMEBREW_PREFIX@@/opt/lapack/lib -llapack 
LAPACKINC           =  -I@@HOMEBREW_PREFIX@@/opt/lapack/include

#GDAL/OGR
GDALLIBS            = -L@@HOMEBREW_CELLAR@@/osgeo-gdal/2.4.1_1/lib -lgdal
GDALCFLAGS          = -I@@HOMEBREW_CELLAR@@/osgeo-gdal/2.4.1_1/include
USE_GDAL            = 1
USE_OGR             = 1

#NetCDF
NETCDFLIBS          = -L@@HOMEBREW_CELLAR@@/osgeo-netcdf/4.6.3_1/lib -lnetcdf
NETCDFCFLAGS        = -I@@HOMEBREW_CELLAR@@/osgeo-netcdf/4.6.3_1/include    
USE_NETCDF          = 1

#LAS LiDAR through libLAS
LASLIBS             = -L@@HOMEBREW_CELLAR@@/osgeo-liblas/1.8.1_5/lib -llas -llas_c -L@@HOMEBREW_PREFIX@@/lib @@HOMEBREW_PREFIX@@/lib/libboost_program_options-mt.dylib @@HOMEBREW_PREFIX@@/lib/libboost_thread-mt.dylib @@HOMEBREW_PREFIX@@/opt/osgeo-gdal/lib/libgdal.dylib @@HOMEBREW_PREFIX@@/opt/osgeo-libgeotiff/lib/libgeotiff.dylib @@HOMEBREW_PREFIX@@/opt/libtiff/lib/libtiff.dylib @@HOMEBREW_PREFIX@@/opt/libxml2/lib/libxml2.dylib @@HOMEBREW_PREFIX@@/opt/osgeo-laszip@2/lib/liblaszip.dylib
LASCFLAGS           = -I@@HOMEBREW_CELLAR@@/osgeo-liblas/1.8.1_5/include -I@@HOMEBREW_PREFIX@@/opt/osgeo-gdal/include -I@@HOMEBREW_PREFIX@@/opt/osgeo-libgeotiff/include -I@@HOMEBREW_PREFIX@@/opt/libtiff/include -I@@HOMEBREW_PREFIX@@/opt/libxml2/include -I@@HOMEBREW_PREFIX@@/opt/osgeo-laszip@2/include/liblas
LASINC              = -I@@HOMEBREW_CELLAR@@/osgeo-liblas/1.8.1_5/include -I@@HOMEBREW_PREFIX@@/opt/osgeo-gdal/include -I@@HOMEBREW_PREFIX@@/opt/osgeo-libgeotiff/include -I@@HOMEBREW_PREFIX@@/opt/libtiff/include -I@@HOMEBREW_PREFIX@@/opt/libxml2/include -I@@HOMEBREW_PREFIX@@/opt/osgeo-laszip@2/include
USE_LIBLAS          = 1

#LAS LiDAR through PDAL
PDALLIBS             = 
PDALCPPFLAGS         = 
PDALINC              = 
USE_PDAL             = 

#GEOS
GEOSLIBS            = -L@@HOMEBREW_CELLAR@@/geos/3.7.1_1/lib -lgeos_c -lgeos_c 
GEOSCFLAGS          = -I@@HOMEBREW_CELLAR@@/geos/3.7.1_1/include
USE_GEOS            = 1

#FreeType:
FTINC               =  -I@@HOMEBREW_PREFIX@@/opt/freetype/include/freetype2
FTLIB               =  -L@@HOMEBREW_PREFIX@@/opt/freetype/lib -lfreetype 

#PROJ.4:
PROJINC             =  -I@@HOMEBREW_PREFIX@@/opt/osgeo-proj/include
PROJLIB             =  -L@@HOMEBREW_PREFIX@@/opt/osgeo-proj/lib -lproj 
PROJSHARE           = @@HOMEBREW_PREFIX@@/opt/osgeo-proj/share/proj

#OPENDWG:
OPENDWGINCPATH      = 
OPENDWGLIBPATH      = 
OPENDWGLIB          = 
USE_OPENDWG         = 

#cairo
CAIROINC                  = -I@@HOMEBREW_CELLAR@@/zlib/1.2.11/include -I@@HOMEBREW_CELLAR@@/libpng/1.6.36/include/libpng16 -I@@HOMEBREW_PREFIX@@/opt/freetype/include/freetype2 -I@@HOMEBREW_CELLAR@@/fontconfig/2.13.1/include -I@@HOMEBREW_CELLAR@@/libffi/3.2.1/lib/libffi-3.2.1/include -I@@HOMEBREW_CELLAR@@/pcre/8.43/include -I@@HOMEBREW_CELLAR@@/glib/2.60.0_1/include -I@@HOMEBREW_CELLAR@@/glib/2.60.0_1/include/glib-2.0 -I@@HOMEBREW_CELLAR@@/glib/2.60.0_1/lib/glib-2.0/include -I@@HOMEBREW_PREFIX@@/opt/gettext/include -I@@HOMEBREW_CELLAR@@/pixman/0.38.0/include/pixman-1 -I@@HOMEBREW_CELLAR@@/cairo/1.16.0/include/cairo -I/opt/X11/include/cairo -I/opt/X11/include -I@@HOMEBREW_PREFIX@@/opt/cairo/include/cairo
CAIROLIB                  = -L@@HOMEBREW_PREFIX@@/opt/freetype/lib -L@@HOMEBREW_CELLAR@@/fontconfig/2.13.1/lib -L@@HOMEBREW_CELLAR@@/cairo/1.16.0/lib -L/opt/X11/lib -lz -lfontconfig -lfreetype -lcairo -lXext -lXrender -lX11 -L@@HOMEBREW_PREFIX@@/opt/cairo/lib -lfontconfig 
USE_CAIRO                 = 1
CAIRO_HAS_XRENDER         = 
CAIRO_HAS_XRENDER_SURFACE = 

#Python
PYTHON              = python

#regex
REGEXINCPATH        = 
REGEXLIBPATH        = 
REGEXLIB            =  
USE_REGEX           = 1

#pthreads
PTHREADINCPATH      =  -I@@HOMEBREW_PREFIX@@/opt/boost/include/boost/thread
PTHREADLIBPATH      =  -L@@HOMEBREW_PREFIX@@/opt/boost/lib
PTHREADLIB          =  
USE_PTHREAD         = 1

#OpenMP
OMPINCPATH          = 
OMPLIBPATH          = 
OMPLIB              = 
OMPCFLAGS           = 
USE_OPENMP          = 

#OpenCL
OCLINCPATH          = 
OCLLIBPATH          = 
OCLLIB              = 
USE_OPENCL          = 

#i18N
HAVE_NLS            = 1

#Large File Support (LFS)
USE_LARGEFILES      = 1
LFS_CFLAGS          = 

#BSD sockets
HAVE_SOCKET         = 1

MINGW		    = 
MACOSX_APP	    = 
MACOSX_ARCHS        =  -arch x86_64
MACOSX_SDK          = -isysroot /Applications/Xcode-8.3.3.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.12.sdk

# Cross compilation
CROSS_COMPILING     =  
